# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '.\haige_pyqt\uis\about.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_aboutFrm(object):
    def setupUi(self, aboutFrm):
        aboutFrm.setObjectName("aboutFrm")
        aboutFrm.resize(371, 365)
        self.label = QtWidgets.QLabel(aboutFrm)
        self.label.setGeometry(QtCore.QRect(20, 10, 91, 41))
        font = QtGui.QFont()
        font.setFamily("华文中宋")
        font.setPointSize(14)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.lb_picture = QtWidgets.QLabel(aboutFrm)
        self.lb_picture.setGeometry(QtCore.QRect(21, 64, 320, 260))
        self.lb_picture.setText("")
        self.lb_picture.setObjectName("lb_picture")

        self.retranslateUi(aboutFrm)
        QtCore.QMetaObject.connectSlotsByName(aboutFrm)

    def retranslateUi(self, aboutFrm):
        _translate = QtCore.QCoreApplication.translate
        aboutFrm.setWindowTitle(_translate("aboutFrm", "关于作者"))
        self.label.setText(_translate("aboutFrm", "联系作者"))
